var examples =
[
    [ "Scale_space_reconstruction_3/scale_space.cpp", "Scale_space_reconstruction_3_2scale_space_8cpp-example.html", null ],
    [ "Scale_space_reconstruction_3/scale_space_sm.cpp", "Scale_space_reconstruction_3_2scale_space_sm_8cpp-example.html", null ],
    [ "Scale_space_reconstruction_3/scale_space_incremental.cpp", "Scale_space_reconstruction_3_2scale_space_incremental_8cpp-example.html", null ],
    [ "Scale_space_reconstruction_3/scale_space_manifold.cpp", "Scale_space_reconstruction_3_2scale_space_manifold_8cpp-example.html", null ],
    [ "Scale_space_reconstruction_3/scale_space_advancing_front.cpp", "Scale_space_reconstruction_3_2scale_space_advancing_front_8cpp-example.html", null ]
];